# ssi_pingme


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

# Dev mode

``` sh
#Create the dev environment in ./.venv then activate it so you're working in it
conda env create -p ./.venv --file conda.dev.env.yaml
conda activate ./.venv
#Need to add kernel to jupyterhub for processing on server, ipykernel is part of conda.dev.env.yaml
python -m ipykernel install --user --name=Pingme
#After this change your kernel to Pingme via JupyterHub (top right of a notebook)

#Now we need to create the repo locally
nbdev_export

#with it created we can install the dev env
pip install -e '.[dev]'
#optional test to ensure it worked
core_hello_world test #to test everything works

#now we can do nbdev_prepare
nbdev_prepare
```

## Install

``` sh
pip install ssi_pingme
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
1 + 1
```

    2
